<?php

namespace Labrender\FileRepository\Providers;

use Illuminate\Support\ServiceProvider;

class FileRepositoryServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = false;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../../../resources/views', 'file_repository');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../../../resources/lang', 'file_repository');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        // Bind facade
        $this->app->bind('file_repository', function ($app) {
            return $this->app->make('Labrender\FileRepository\FileRepository');
        });

// Bind Notifications to repository
        $this->app->bind(
            'Labrender\FileRepository\Interfaces\NotificationsRepositoryInterface',
            \Labrender\FileRepository\Repositories\Eloquent\NotificationsRepository::class
        );        // Bind Attachments to repository
        $this->app->bind(
            'Labrender\FileRepository\Interfaces\AttachmentsRepositoryInterface',
            \Labrender\FileRepository\Repositories\Eloquent\AttachmentsRepository::class
        );

        $this->app->register(\Labrender\FileRepository\Providers\AuthServiceProvider::class);
        $this->app->register(\Labrender\FileRepository\Providers\EventServiceProvider::class);
        $this->app->register(\Labrender\FileRepository\Providers\RouteServiceProvider::class);
        // $this->app->register(\Labrender\FileRepository\Providers\WorkflowServiceProvider::class);
    }

    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['file_repository'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../../../config/config.php' => config_path('labrender/file_repository.php')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../../../resources/views' => base_path('resources/views/vendor/file_repository')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../../../resources/lang' => base_path('resources/lang/vendor/file_repository')], 'lang');

        // Publish migrations
        $this->publishes([__DIR__ . '/../../../../database/migrations/' => base_path('database/migrations')], 'migrations');

        // Publish seeds
        $this->publishes([__DIR__ . '/../../../../database/seeds/' => base_path('database/seeds')], 'seeds');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
