<?php

namespace Labrender\FileRepository\Providers;

use Litepie\Contracts\Workflow\Workflow as WorkflowContract;
use Litepie\Foundation\Support\Providers\WorkflowServiceProvider as ServiceProvider;

class WorkflowServiceProvider extends ServiceProvider
{
    /**
     * The validators mappings for the package.
     *
     * @var array
     */
    protected $validators = [
        // Bind Notifications validator
        \Labrender\FileRepository\Models\Notifications::class => \Labrender\FileRepository\Workflow\NotificationsValidator::class,
        // Bind Attachments validator
        \Labrender\FileRepository\Models\Attachments::class => \Labrender\FileRepository\Workflow\AttachmentsValidator::class,
    ];

    /**
     * The actions mappings for the package.
     *
     * @var array
     */
    protected $actions = [
        // Bind Notifications actions
        \Labrender\FileRepository\Models\Notifications::class => \Labrender\FileRepository\Workflow\NotificationsAction::class,
        // Bind Attachments actions
        \Labrender\FileRepository\Models\Attachments::class => \Labrender\FileRepository\Workflow\AttachmentsAction::class,
    ];

    /**
     * The notifiers mappings for the package.
     *
     * @var array
     */
    protected $notifiers = [
       // Bind Notifications notifiers
        \Labrender\FileRepository\Models\Notifications::class => \Labrender\FileRepository\Workflow\NotificationsNotifier::class,
        // Bind Attachments notifiers
        \Labrender\FileRepository\Models\Attachments::class => \Labrender\FileRepository\Workflow\AttachmentsNotifier::class,
    ];

    /**
     * Register any package workflow validation services.
     *
     * @param \Litepie\Contracts\Workflow\Workflow $workflow
     *
     * @return void
     */
    public function boot(WorkflowContract $workflow)
    {
        parent::registerValidators($workflow);
        parent::registerActions($workflow);
        parent::registerNotifiers($workflow);
    }
}
