<?php

namespace Labrender\FileRepository\Workflow;

use Exception;
use Litepie\Workflow\Exceptions\WorkflowActionNotPerformedException;

use Labrender\FileRepository\Models\Notifications;

class NotificationsAction
{
    /**
     * Perform the complete action.
     *
     * @param Notifications $notifications
     *
     * @return Notifications
     */
    public function complete(Notifications $notifications)
    {
        try {
            $notifications->status = 'complete';
            return $notifications->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the verify action.
     *
     * @param Notifications $notifications
     *
     * @return Notifications
     */public function verify(Notifications $notifications)
    {
        try {
            $notifications->status = 'verify';
            return $notifications->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the approve action.
     *
     * @param Notifications $notifications
     *
     * @return Notifications
     */public function approve(Notifications $notifications)
    {
        try {
            $notifications->status = 'approve';
            return $notifications->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the publish action.
     *
     * @param Notifications $notifications
     *
     * @return Notifications
     */public function publish(Notifications $notifications)
    {
        try {
            $notifications->status = 'publish';
            return $notifications->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the archive action.
     *
     * @param Notifications $notifications
     *
     * @return Notifications
     */
    public function archive(Notifications $notifications)
    {
        try {
            $notifications->status = 'archive';
            return $notifications->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the unpublish action.
     *
     * @param Notifications $notifications
     *
     * @return Notifications
     */
    public function unpublish(Notifications $notifications)
    {
        try {
            $notifications->status = 'unpublish';
            return $notifications->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }
}
